==> igniteui-webcomponents-core-3.2.2.tgz: package/esm5/lib/SummaryCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { SummaryCellInfoDescription } from "./SummaryCellInfoDescription";
/**
 * @hidden
 */
var SummaryCellInfoDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(SummaryCellInfoDescriptionMetadata, _super);
    function SummaryCellInfoDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SummaryCellInfoDescriptionMetadata.b = function (a) {
        if (SummaryCellInfoDescriptionMetadata.a == null) {
            SummaryCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SummaryCellInfoDescriptionMetadata.c(SummaryCellInfoDescriptionMetadata.a);
        }
        if (a.g(SummaryCellInfoDescriptionMetadata.a)) {
            return;
        }
        a.s(SummaryCellInfoDescriptionMetadata.a);
    };
    SummaryCellInfoDescriptionMetadata.c = function (a) {
        CellInfoDescriptionMetadata.c(a);
        a.item("ResolvedSummaryLabel", "String");
        a.item("ResolvedSummaryValue", "String");
        a.item("SummaryLabelTextColor", "Brush");
        a.item("SummaryLabelFontFamily", "(w:SummaryLabelFontFamily/FontFamilyTransform,xam:SummaryLabelFontFamily,wf:SummaryLabelFontFamily,web:font/FontFamilyTransform)String");
        a.item("SummaryLabelFontSize", "(w:SummaryLabelFontSize,xam:SummaryLabelFontSize,wf:SummaryLabelFontSize,web:font/FontSizeTransform)Number:double");
        a.item("SummaryLabelFontStyle", "(w:SummaryLabelFontStyle/FontStyleTransform,xam:SummaryLabelFontFamily/FontStyleTransform,wf:SummaryLabelFontFamily/FontStyleTransform,web:font/FontStyleTransform)String");
        a.item("SummaryLabelFontWeight", "(w:SummaryLabelFontWeight/FontWeightTransform,xam:SummaryLabelFontFamily/FontWeightTransform,wf:SummaryLabelFontFamily/FontWeightTransform,web:font/FontWeightTransform)String");
    };
    SummaryCellInfoDescriptionMetadata.d = function (a) {
        SummaryCellInfoDescriptionMetadata.b(a);
        a.u("SummaryCellInfo", function () { return new SummaryCellInfoDescription(); });
        a.t("SummaryCellInfo", SummaryCellInfoDescriptionMetadata.a);
    };
    SummaryCellInfoDescriptionMetadata.$t = markType(SummaryCellInfoDescriptionMetadata, 'SummaryCellInfoDescriptionMetadata');
    SummaryCellInfoDescriptionMetadata.a = null;
    return SummaryCellInfoDescriptionMetadata;
}(Base));
export { SummaryCellInfoDescriptionMetadata };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/SummaryCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { SummaryCellInfoDescription } from "./SummaryCellInfoDescription";
/**
 * @hidden
 */
var SummaryCellInfoDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(SummaryCellInfoDescriptionMetadata, _super);
    function SummaryCellInfoDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SummaryCellInfoDescriptionMetadata.b = function (a) {
        if (SummaryCellInfoDescriptionMetadata.a == null) {
            SummaryCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SummaryCellInfoDescriptionMetadata.c(SummaryCellInfoDescriptionMetadata.a);
        }
        if (a.j(SummaryCellInfoDescriptionMetadata.a)) {
            return;
        }
        a.y(SummaryCellInfoDescriptionMetadata.a);
    };
    SummaryCellInfoDescriptionMetadata.c = function (a) {
        CellInfoDescriptionMetadata.c(a);
        a.item("ResolvedSummaryLabel", "String");
        a.item("ResolvedSummaryValue", "String");
        a.item("SummaryLabelTextColor", "Brush");
        a.item("SummaryLabelFontFamily", "(w:SummaryLabelFontFamily/FontFamilyTransform,xam:SummaryLabelFontFamily,wf:SummaryLabelFontFamily,web:font/FontFamilyTransform)String");
        a.item("SummaryLabelFontSize", "(w:SummaryLabelFontSize,xam:SummaryLabelFontSize,wf:SummaryLabelFontSize,web:font/FontSizeTransform)Number:double");
        a.item("SummaryLabelFontStyle", "(w:SummaryLabelFontStyle/FontStyleTransform,xam:SummaryLabelFontFamily/FontStyleTransform,wf:SummaryLabelFontFamily/FontStyleTransform,web:font/FontStyleTransform)String");
        a.item("SummaryLabelFontWeight", "(w:SummaryLabelFontWeight/FontWeightTransform,xam:SummaryLabelFontFamily/FontWeightTransform,wf:SummaryLabelFontFamily/FontWeightTransform,web:font/FontWeightTransform)String");
    };
    SummaryCellInfoDescriptionMetadata.d = function (a) {
        SummaryCellInfoDescriptionMetadata.b(a);
        a.aa("SummaryCellInfo", function () { return new SummaryCellInfoDescription(); });
        a.z("SummaryCellInfo", SummaryCellInfoDescriptionMetadata.a);
    };
    SummaryCellInfoDescriptionMetadata.$t = markType(SummaryCellInfoDescriptionMetadata, 'SummaryCellInfoDescriptionMetadata');
    SummaryCellInfoDescriptionMetadata.a = null;
    return SummaryCellInfoDescriptionMetadata;
}(Base));
export { SummaryCellInfoDescriptionMetadata };
